@@ -1,10 +1,20 @@
 """Provide a model for the Z-Wave JS value."""
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, TypedDict, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
 
-from ..const import VALUE_UNKNOWN, CommandClass, ConfigurationValueType
+from ..const import (
+    TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED,
+    VALUE_UNKNOWN,
+    CommandClass,
+    ConfigurationValueType,
+)
 from ..event import Event
 from ..util.helpers import parse_buffer
 
+if TYPING_EXTENSION_FOR_TYPEDDICT_REQUIRED:
+    from typing_extensions import TypedDict
+else:
+    from typing import TypedDict
+
 if TYPE_CHECKING:
     from .node import Node
 
@@ -254,12 +264,15 @@ class Value:
         """Update data."""
         self.data.update(data)
         if "newValue" in data:
-            self._value = data["newValue"]
+            self._value = self.data["value"] = data["newValue"]
         if "value" in data:
-            self._value = data["value"]
+            self._value = self.data["value"] = data["value"]
         if "metadata" in data:
             self._metadata.update(data["metadata"])
 
+        self.data.pop("newValue", None)
+        self.data.pop("prevValue", None)
+
         # Handle buffer dict and json string in value.
         if self.metadata.type == "buffer":
             self._value = parse_buffer(self._value)
